@@ -7,16 +7,18 @@ from aws_cdk import (
 
 ##
 ## CodeCommit
-def createCodeCommitRepository(self, repository_name):
+def createCodeCommitRepository(self, repository_name, initial_commit=None):
     """
     Creates a CodeCommit Repository.
  
     :param repository_name: Name of the CodeCommit Repository
+    :param initial_commit: CodeCommit Repository Initial Commit (defaul=None)
     :return: CodeCommit Repository Object
     """ 
     repo = codecommit.Repository(
         self, 'CDK-CodeCommit-Repository-{}'.format(repository_name),
-        repository_name= repository_name
+        repository_name= repository_name,
+        code=initial_commit
     )
     return repo
 
